[![PyPI version](https://badge.fury.io/py/plumbing.svg)](https://badge.fury.io/py/plumbing)

# `plumbing` version 2.7.9

This project contains functions and classes that help with plumbing-type programing.

More documentation is available at:
<http://xapple.github.io/plumbing/>